"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var Placeholder_1 = __importDefault(require("./Placeholder"));
var Box_1 = __importDefault(require("./Box"));
var Column_1 = __importDefault(require("./Column"));
var Columns_1 = __importDefault(require("./Columns"));
var Container = function (_a) {
    var children = _a.children;
    return (react_1.default.createElement(Box_1.default, { bgcolor: '#ddd' }, children));
};
var docs = {
    name: 'Columns',
    examples: [
        {
            description: 'No space',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, null,
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })))); },
        },
        {
            description: 'Custom space',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })))); },
        },
        {
            description: 'Responsive space',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { space: [2, 3, 4] },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })))); },
        },
        {
            description: 'Vertically align to center',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { alignY: 'center', space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 100 })))); },
        },
        {
            description: 'Vertically align to top',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { alignY: 'top', space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 100 })))); },
        },
        {
            description: 'Vertically align to bottom',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { alignY: 'bottom', space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 100 })))); },
        },
        {
            description: 'Responsive alignment',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { alignY: ['bottom', 'center', 'top'], space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60 })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 100 })))); },
        },
        {
            description: 'Collapse below md',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { collapseBelow: 'md', space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'First' })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'Second' })))); },
        },
        {
            description: 'Collapse below lg',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { collapseBelow: 'lg', space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'First' })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'Second' })))); },
        },
        {
            description: 'Collapse below md with responsive space',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { collapseBelow: 'md', space: [2, 3, 4] },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'First' })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'Second' })))); },
        },
        {
            description: 'Reverse',
            Container: Container,
            Example: function () { return (react_1.default.createElement(Columns_1.default, { reverse: true, space: 2 },
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'First' })),
                react_1.default.createElement(Column_1.default, null,
                    react_1.default.createElement(Placeholder_1.default, { height: 60, label: 'Second' })))); },
        },
    ],
};
exports.default = docs;
